import { Component, OnInit, Inject, Renderer2 } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material';
import { KEY_LOGIN_RES_INFO, KEY_VER_INFO } from '@app/types';
import { SessionStorageService } from '@ucap-webmessenger/web-storage';

import { Store } from '@ngrx/store';

import { DialogService } from '@ucap-webmessenger/ui';
import { VersionInfo2Response } from '@ucap-webmessenger/api-public';
import { LoginResponse } from '@ucap-webmessenger/protocol-authentication';
import { map } from 'rxjs/operators';
import { DOCUMENT } from '@angular/common';

export interface MessengerSettingsDialogData {}

export interface MessengerSettingsDialogResult {}

@Component({
  selector: 'app-messenger-settings-dialog',
  templateUrl: './messenger-settings.dialog.component.html',
  styleUrls: ['./messenger-settings.dialog.component.scss']
})
export class MessengerSettingsDialogComponent implements OnInit {
  loginRes: LoginResponse;
  sessionVerinfo: VersionInfo2Response;

  constructor(
    public dialogRef: MatDialogRef<
      MessengerSettingsDialogData,
      MessengerSettingsDialogResult
    >,
    @Inject(MAT_DIALOG_DATA) public data: MessengerSettingsDialogData,
    private dialogService: DialogService,
    private sessionStorageService: SessionStorageService,
    private store: Store<any>,
    @Inject(DOCUMENT) private document: Document,
    private renderer2: Renderer2
  ) {
    this.sessionVerinfo = this.sessionStorageService.get<VersionInfo2Response>(
      KEY_VER_INFO
    );
    this.loginRes = this.sessionStorageService.get<LoginResponse>(
      KEY_LOGIN_RES_INFO
    );
  }

  ngOnInit() {}

  onSelectTheme(theme: string): void {
    this.renderer2.setAttribute(this.document.body, 'class', theme);
  }

  onClickChoice(choice: boolean): void {
    this.dialogRef.close({});
  }
}
